PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/gaunt.h File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Variables
gaunt.h File Reference

Go to the source code of this file.

## Variables
double | GAUNT_COEFF [4][4][4][7][4]
double | SBTFACS [4][4][4][7][4]

## Detailed Description

Stores gaunt coefficients and offsite overlap integral factors. Access as l1, l2, (L-|l1-l2|)/2, l1+m1, m2. Constrained by l1 >= l2, m2 >= 0, L >= |l1-l2|, L <= l1+l2

## Variable Documentation

double GAUNT_COEFF[4][4][4][7][4]

double SBTFACS[4][4][4][7][4]